@@ -1,28 +1,26 @@
-/*
-   Default preferences for new profiles
-   */
 user_pref("app.normandy.enabled", false);
 user_pref("app.shield.optoutstudies.enabled", false);
 user_pref("beacon.enabled", false);
+user_pref("browser.aboutwelcome.enabled", false);
 user_pref("browser.aboutConfig.showWarning", false);
 user_pref("browser.customizemode.tip0.shown", true);
 user_pref("browser.disableResetPrompt", true);
-user_pref("browser.reader.detectedFirstArticle", true);
 user_pref("browser.fixup.alternate.enabled", false);
 user_pref("browser.fixup.alternate.suffix", ".invalid");
 user_pref("browser.library.activity-stream.enabled", false);
 user_pref("browser.newtabpage.activity-stream.asrouter.disable-captive-portal-vpn-promo", true);
-user_pref("browser.newtabpage.activity-stream.feeds.snippets", false);
-user_pref("browser.newtab.preload", false);
 user_pref("browser.newtabpage.activity-stream.asrouter.userprefs.cfr.addons", false);
 user_pref("browser.newtabpage.activity-stream.asrouter.userprefs.cfr.features", false);
 user_pref("browser.newtabpage.activity-stream.feeds.section.highlights", false);
+user_pref("browser.newtabpage.activity-stream.feeds.snippets", false);
 user_pref("browser.newtabpage.activity-stream.feeds.topsites", false);
 user_pref("browser.newtabpage.enabled", false);
 user_pref("browser.newtabpage.enhanced", false);
 user_pref("browser.newtabpage.introShown", true);
+user_pref("browser.newtab.preload", false);
 user_pref("browser.privatebrowsing.promoEnabled", false);
 user_pref("browser.privatebrowsing.promoTitleEnabled", false);
+user_pref("browser.reader.detectedFirstArticle", true);
 user_pref("browser.search.hiddenOneOffs", "Google,Amazon.com,Bing,DuckDuckGo,Wikipedia (en)");
 user_pref("browser.search.suggest.enabled", false);
 user_pref("browser.selfsupport.url", "");
@@ -32,16 +30,21 @@ user_pref("browser.startup.blankWindow", true);
 user_pref("browser.startup.homepage", "about:blank");
 user_pref("browser.toolbarbuttons.introduced.pocket-button", true);
 user_pref("browser.toolbars.bookmarks.2h2020", false);
+user_pref("browser.urlbar.suggest.quicksuggest.sponsored", false);
 user_pref("browser.urlbar.trimURLs", false);
 user_pref("datareporting.healthreport.service.enabled", false);
 user_pref("datareporting.healthreport.uploadEnabled", false);
 user_pref("datareporting.policy.dataSubmissionEnabled", false);
-user_pref("dom.event.clipboardevents.enabled", false);
+user_pref("devtools.everOpened", true);
+user_pref("devtools.jsonview.enabled", false);
+user_pref("devtools.netmonitor.persistlog", true);
+user_pref("devtools.webconsole.persistlog", true);
 user_pref("dom.battery.enabled", false);
+user_pref("dom.event.clipboardevents.enabled", false);
 user_pref("experiments.enabled", false);
-user_pref("extensions.htmlaboutaddons.recommendations.enabled", false);
 user_pref("experiments.supported", false);
 user_pref("extensions.getAddons.cache.enabled", false);
+user_pref("extensions.htmlaboutaddons.recommendations.enabled", false);
 user_pref("extensions.pocket.enabled", false);
 user_pref("extensions.privatebrowsing.notification", true);
 user_pref("extensions.recommendations.hideNotice", true);
@@ -50,11 +53,12 @@ user_pref("extensions.shownSelectionUI", true);
 user_pref("general.warnOnAboutConfig", false);
 user_pref("geo.enabled", false);
 user_pref("keyword.enabled", false);
+user_pref("layout.spellcheckDefault", 0);
 user_pref("media.navigator.enabled", false);
 user_pref("media.peerconnection.enabled", false);
+user_pref("media.videocontrols.picture-in-picture.video-toggle.enabled", false);
 user_pref("media.video_stats.enabled", false);
 user_pref("middlemouse.contentLoadURL", false);
-user_pref("media.videocontrols.picture-in-picture.video-toggle.enabled", false);
 user_pref("network.allow-experiments", false);
 user_pref("network.captive-portal-service.enabled", false);
 user_pref("network.cookie.cookieBehavior", 1);
@@ -64,11 +68,20 @@ user_pref("network.predictor.enabled", false);
 user_pref("network.prefetch-next", false);
 user_pref("network.trr.mode", 0);
 user_pref("pdfjs.enablescripting", false);
+user_pref("print.more-settings.open", true);
 user_pref("privacy.donottrackheader.enabled", true);
 user_pref("privacy.donottrackheader.value", 1);
+user_pref("privacy.query_stripping.enabled", true);
+user_pref("privacy.query_stripping", true);
 user_pref("privacy.resistFingerprinting", false);
 user_pref("privacy.trackingprotection.enabled", true);
 user_pref("privacy.trackingprotection.introCount", 20);
 user_pref("privacy.trackingprotection.pbmode.enabled", true);
 user_pref("signon.includeOtherSubdomainsInLookup", false);
+user_pref("startup.homepage_welcome_url", "about:blank");
+user_pref("toolkit.legacyUserProfileCustomizations.stylesheets", true);
 user_pref("toolkit.telemetry.enabled", false);
+user_pref("toolkit.telemetry.prompted", 2);
+user_pref("toolkit.telemetry.rejected", true);
+user_pref("toolkit.telemetry.unifiedIsOptIn", false);
+user_pref("trailhead.firstrun.didSeeAboutWelcome", true);
